@@ -1,12 +1,13 @@
 """tracker specific entities class for Ticket
 
 :organization: Logilab
-:copyright: 2006-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+:copyright: 2006-2011 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 :contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
 """
 
 __docformat__ = "restructuredtext en"
 
+from rql import nodes
 from cubicweb.entities import AnyEntity
 
 
@@ -18,12 +19,14 @@ class Ticket(AnyEntity):
     OPEN_STATES = frozenset(('created', 'in-progress',))
 
     @classmethod
-    def fetch_order(cls, attr, var):
+    def cw_fetch_order(cls, select, attr, var):
         if attr == 'priority':
-            return 'priority_sort_value(%s)' % var
-        if attr in ('title', 'type'):
-            return var
-        return None
+            func = nodes.Function('priority_sort_value')
+            func.append(nodes.variable_ref(var))
+            sterm = nodes.SortTerm(func, asc=False)
+            select.add_sort_term(sterm)
+        elif attr in ('title', 'type'):
+            select.add_sort_var(var)
 
     @property
     def project(self):
@@ -72,4 +75,6 @@ class Ticket(AnyEntity):
     def sortvalue(self, rtype=None):
         if rtype == 'priority':
             return ['minor', 'normal', 'important'].index(self.priority)
+        if rtype is None:
+            return self.eid
         return super(Ticket, self).sortvalue(rtype)
