@@ -1,13 +1,13 @@
 """tracker post creation script, set application's workflows
 
 :organization: Logilab
-:copyright: 2003-2009 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+:copyright: 2003-2011 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 :contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
 """
 __docformat__ = "restructuredtext en"
 _ = unicode
 
-from cubes.tracker.schemaperms import xperm
+from cubes.localperms import xperm
 
 # Ticket workflow
 twf = add_workflow(_('default ticket workflow'), 'Ticket')
