@@ -12,7 +12,8 @@ WITH(ISCACHABLE);;
 
 CREATE OR REPLACE FUNCTION version_sort_value(text) RETURNS bigint AS $$
     try:
-        return sum([(10000, 100, 1)[i]*int(v) for i, v in enumerate(args[0].split("."))])
+        version, _sep, revision = args[0].partition('-')
+        return sum([1000000,10000,100][i]*int(v) for i, v in enumerate(version.split("."))) + int(revision or 0)
     except (ValueError, IndexError, AttributeError):
         return 0
 $$ LANGUAGE plpythonu
