@@ -1,16 +1,15 @@
 """tracker server side objects, mainly notification stuff
 
 :organization: Logilab
-:copyright: 2006-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+:copyright: 2006-2011 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 :contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
 """
 __docformat__ = "restructuredtext en"
-
+_ = unicode
 
 from logilab.common.textutils import normalize_text
 
 from cubicweb.selectors import is_instance, score_entity
-from cubicweb.mail import SkipEmail
 from cubicweb.sobjects.notification import (StatusChangeMixIn, NotificationView,
                                             EntityUpdatedNotificationView)
 
@@ -26,7 +25,7 @@ def version_is_published(version):
 class TrackerEmailView(NotificationView):
 
     def subject(self):
-        entity = self.cw_rset.get_entity(0,0)
+        entity = self.cw_rset.get_entity(0, 0)
         return '[%s] %s' % (entity.project.name, self._subject(entity))
 
     def _subject(self, entity):
@@ -183,4 +182,4 @@ URL
 
     def _subject(self, entity):
         return self._cw._('%(etype)s added: %(title)s') % {
-            'etype': str(entity.e_schema).lower(), 'title': entity.dc_title()}
+            'etype': entity.dc_type(), 'title': entity.dc_title()}
