@@ -1,10 +1,11 @@
 """tracker web user interface
 
 :organization: Logilab
-:copyright: 2006-2009 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+:copyright: 2006-2011 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 :contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
 """
 __docformat__ = "restructuredtext en"
+_ = unicode
 
 from cubicweb.web import uicfg
 from cubicweb.web.views import schema
@@ -16,6 +17,20 @@ schema.SKIP_TYPES.add('see_also')
 schema.ALWAYS_SKIP_TYPES.add('see_also')
 
 
+def fixed_orderby_rql(sortsdef, asc=True):
+    orderby = []
+    for rtype, varname in sortsdef:
+        if rtype == 'priority':
+            orderby.append('priority_sort_value(%s)' % varname)
+        elif rtype == 'num':
+            orderby.append('version_sort_value(%s)' % varname)
+        else:
+            orderby.append(varname)
+    if asc:
+        return 'ORDERBY %s' % ', '.join(orderby)
+    return 'ORDERBY %s DESC' % ', '.join(orderby)
+
+
 class TrackerSimpleReqRewriter(SimpleReqRewriter):
     """handle path with the form::
 
